@@ -1,20 +1,20 @@
-from bolinette import types, blnt, core
+from bolinette import types, core, blnt, mapping
 from bolinette.decorators import model
 
 
 @model('users_roles')
-class UsersRoles(blnt.Model):
+class UsersRoles(core.Model):
     user_id = types.defs.Column(types.db.Integer, reference=types.defs.Reference('user', 'id'), primary_key=True)
     role_id = types.defs.Column(types.db.Integer, reference=types.defs.Reference('role', 'id'), primary_key=True)
 
 
 @model('user')
-class User(blnt.Model):
+class User(core.Model):
     id = types.defs.Column(types.db.Integer, primary_key=True)
     username = types.defs.Column(types.db.String, unique=True, nullable=False)
     password = types.defs.Column(types.db.Password, nullable=False)
-    email = types.defs.Column(types.db.Email, unique=core.init['USER_EMAIL_REQUIRED'],
-                              nullable=(not core.init['USER_EMAIL_REQUIRED']))
+    email = types.defs.Column(types.db.Email, unique=blnt.init['user_email_required'],
+                              nullable=(not blnt.init['user_email_required']))
 
     roles = types.defs.Relationship('role', secondary='users_roles', lazy='subquery',
                                     backref=types.defs.Backref('users', lazy=True))
@@ -27,30 +27,30 @@ class User(blnt.Model):
     @classmethod
     def payloads(cls):
         yield 'register', [
-            types.mapping.Column(cls.username, required=True),
-            types.mapping.Column(cls.email, required=True),
-            types.mapping.Column(cls.password, required=True),
-            types.mapping.Column(cls.timezone)
+            mapping.Column(cls.username, required=True),
+            mapping.Column(cls.email, required=True),
+            mapping.Column(cls.password, required=True),
+            mapping.Column(cls.timezone)
         ]
         yield 'admin_register', [
-            types.mapping.Column(cls.username, required=True),
-            types.mapping.Column(cls.email, required=True),
-            types.mapping.Field(types.db.Boolean, name='send_mail', required=True)
+            mapping.Column(cls.username, required=True),
+            mapping.Column(cls.email, required=True),
+            mapping.Field(types.db.Boolean, name='send_mail', required=True)
         ]
         yield 'login', [
-            types.mapping.Column(cls.username, required=True),
-            types.mapping.Column(cls.password, required=True)
+            mapping.Column(cls.username, required=True),
+            mapping.Column(cls.password, required=True)
         ]
 
     @classmethod
     def responses(cls):
         default = [
-            types.mapping.Column(cls.username),
-            types.mapping.Reference(cls.profile_picture, 'minimal')
+            mapping.Column(cls.username),
+            mapping.Reference(cls.profile_picture, 'minimal')
         ]
         yield default
         yield 'private', default + [
-            types.mapping.Column(cls.email),
-            types.mapping.List(types.mapping.Definition('role'), key='roles'),
-            types.mapping.Column(cls.timezone)
+            mapping.Column(cls.email),
+            mapping.List(mapping.Definition('role'), key='roles'),
+            mapping.Column(cls.timezone)
         ]
