@@ -1,4 +1,4 @@
-from typing import Callable, List, Dict, Any
+from typing import Callable, List, Dict, Any, Generator, Optional
 
 from aiohttp.web_request import Request
 
@@ -21,7 +21,7 @@ class Controller:
     def service(self) -> 'core.Service':
         return self.context.service(self.__blnt__.service_name)
 
-    def default_routes(self):
+    def default_routes(self) -> List['web.ControllerRoute']:
         return []
 
     def __repr__(self):
@@ -44,29 +44,46 @@ class ControllerProps:
         self.controller = controller
 
     def _get_attribute_of_type(self, attr_type):
-        return dict([(name, attribute)
-                     for name, attribute in vars(self.controller.__class__).items()
-                     if isinstance(attribute, attr_type)])
+        return ((name, attribute)
+                for name, attribute in vars(self.controller.__class__).items()
+                if isinstance(attribute, attr_type))
 
-    def get_routes(self) -> Dict[str, 'ControllerRoute']:
+    def get_routes(self) -> Generator[tuple[str, 'ControllerRoute'], Any, None]:
         return self._get_attribute_of_type(ControllerRoute)
 
 
 class ControllerRoute:
-    def __init__(self, func: Callable, path: str, method: web.HttpMethod,
+    def __init__(self, func: Callable, path: str, method: web.HttpMethod, docstring: Optional[str],
                  expects: 'Expects' = None, returns: 'Returns' = None,
                  inner_route: 'ControllerRoute' = None, middlewares: List[str] = None):
         self.controller = None
         self.func = func
         self.path = path
         self.method = method
+        self.docstring = docstring
         self.expects = expects
         self.returns = returns
         self.inner_route = inner_route
         self._mdw_defs = middlewares or []
         self.middlewares: List['web.Middleware'] = []
 
-    def init_middlewares(self, context: 'blnt.BolinetteContext', from_controller: List[str], system: List[str]):
+    def __repr__(self):
+        return f'<Route {self.method.name} {self.full_path} {self._mdw_defs}>'
+
+    @property
+    def full_path(self):
+        if self.controller is None:
+            return self.path
+        return f'{self.controller.__blnt__.namespace}{self.controller.__blnt__.path}{self.path}'
+
+    def setup(self, controller: 'web.Controller'):
+        self.controller = controller
+        self._init_middlewares(controller.context, controller.__blnt__.middlewares, self._init_sys_middleware())
+        controller.context.resources.add_route(self.full_path, controller, self)
+        if self.inner_route is not None:
+            self.inner_route.setup(controller)
+
+    def _init_middlewares(self, context: 'blnt.BolinetteContext', from_controller: List[str], system: List[str]):
         for mdw in system:
             self._parse_middleware_options(mdw, context, True)
         for mdw in from_controller:
@@ -76,6 +93,30 @@ class ControllerRoute:
         self.middlewares = sorted(sorted(self.middlewares, key=lambda m: m.__blnt__.priority),
                                   key=lambda m: m.system_priority)
 
+    def _init_sys_middleware(self):
+        sys_mdw = [m.__blnt__.name for m in blnt.cache.middlewares.values() if m.__blnt__.auto_load]
+        if self.expects is not None:
+            model = self.expects.model
+            key = self.expects.key if self.expects.key is not None else 'default'
+            cmd = f'blnt_payload|model={model}|key={key}'
+            if self.expects.patch:
+                cmd += '|patch'
+            sys_mdw.append(cmd)
+        else:
+            sys_mdw.append('blnt_payload')
+        if self.returns is not None:
+            model = self.returns.model
+            key = self.returns.key if self.returns.key is not None else 'default'
+            cmd = f'blnt_response|model={model}|key={key}'
+            if self.returns.as_list:
+                cmd += '|as_list'
+            if self.returns.skip_none:
+                cmd += '|skip_none'
+            sys_mdw.append(cmd)
+        else:
+            sys_mdw.append('blnt_response')
+        return sys_mdw
+
     def _parse_middleware_options(self, mdw: str, context, system: bool = False):
         name, *args = mdw.split('|')
         if name.startswith('!'):
@@ -176,62 +217,100 @@ class ControllerDefaults:
     def __init__(self, controller: Controller):
         self.service: core.Service = controller.service
 
-    def get_all(self, returns='default', *, middlewares=None):
+    def get_all(self, returns='default', *, middlewares: List[str] = None, docstring: str = None):
         async def route(controller, **kwargs):
             resp = await functions.async_invoke(controller.service.get_all, **kwargs)
             return controller.response.ok('OK', resp)
 
-        return ControllerRoute(route, '', web.HttpMethod.GET,
-                               returns=Returns(self.service.__blnt__.model_name, returns, as_list=True),
+        model_name = self.service.__blnt__.model_name
+        docstring = docstring or f"""
+        Gets all records from {model_name} collection
+
+        -response 200 returns: The list of {model_name} entities
+        """
+        return ControllerRoute(route, '', web.HttpMethod.GET, docstring,
+                               returns=Returns(model_name, returns, as_list=True),
                                middlewares=middlewares)
 
-    def get_one(self, returns='default', *, key='id', middlewares=None):
+    def get_one(self, returns='default', *, key='id', middlewares: List[str] = None, docstring: str = None):
         async def route(controller, *, match, **kwargs):
-            resp = await functions.async_invoke(controller.service.get_first_by, key, match.get('value'), **kwargs)
+            resp = await functions.async_invoke(controller.service.get_first_by, key, match.get(key), **kwargs)
             return controller.response.ok('OK', resp)
 
-        return ControllerRoute(route, '/{value}', web.HttpMethod.GET,
-                               returns=Returns(self.service.__blnt__.model_name, returns),
+        model_name = self.service.__blnt__.model_name
+        docstring = docstring or f"""
+        Gets one record from {model_name} collection, identified by {key} field
+
+        -response 200 returns: The {model_name} entity
+        """
+        return ControllerRoute(route, f'/{{{key}}}', web.HttpMethod.GET, docstring,
+                               returns=Returns(model_name, returns),
                                middlewares=middlewares)
 
-    def create(self, returns='default', expects='default', *, middlewares=None):
+    def create(self, returns='default', expects='default', *, middlewares: List[str] = None, docstring: str = None):
         async def route(controller, payload, **kwargs):
             resp = await functions.async_invoke(controller.service.create, payload, **kwargs)
             return controller.response.created(f'{controller.service.__blnt__.model_name}.created', resp)
 
-        return ControllerRoute(route, '', web.HttpMethod.POST,
+        model_name = self.service.__blnt__.model_name
+        docstring = docstring or f"""
+        Inserts a new entity in {model_name} collection
+
+        -response 201 returns: The created {model_name} entity
+        """
+        return ControllerRoute(route, '', web.HttpMethod.POST, docstring,
                                expects=Expects(self.service.__blnt__.model_name, expects),
-                               returns=Returns(self.service.__blnt__.model_name, returns),
+                               returns=Returns(model_name, returns),
                                middlewares=middlewares)
 
-    def update(self, returns='default', expects='default', *, key='id', middlewares=None):
+    def update(self, returns='default', expects='default', *, key='id',
+               middlewares: List[str] = None, docstring: str = None):
         async def route(controller, payload, match, **kwargs):
-            entity = await controller.service.get_first_by(key, match.get('value'))
+            entity = await controller.service.get_first_by(key, match.get(key))
             resp = await functions.async_invoke(controller.service.update, entity, payload, **kwargs)
             return controller.response.ok(f'{controller.service.__blnt__.model_name}.updated', resp)
 
-        return ControllerRoute(route, '/{value}', web.HttpMethod.PUT,
+        model_name = self.service.__blnt__.model_name
+        docstring = docstring or f"""
+        Updates all fields from one {model_name} entity, identified by {key} field
+
+        -response 200 returns: The updated {model_name} entity
+        """
+        return ControllerRoute(route, f'/{{{key}}}', web.HttpMethod.PUT, docstring,
                                expects=Expects(self.service.__blnt__.model_name, expects),
-                               returns=Returns(self.service.__blnt__.model_name, returns),
+                               returns=Returns(model_name, returns),
                                middlewares=middlewares)
 
-    def patch(self, returns='default', expects='default', *, key='id', middlewares=None):
+    def patch(self, returns='default', expects='default', *, key='id',
+              middlewares: List[str] = None, docstring: str = None):
         async def route(controller, payload, match, **kwargs):
-            entity = await controller.service.get_first_by(key, match.get('value'))
+            entity = await controller.service.get_first_by(key, match.get(key))
             resp = await functions.async_invoke(controller.service.patch, entity, payload, **kwargs)
             return controller.response.ok(f'{controller.service.__blnt__.model_name}.updated', resp)
 
-        return ControllerRoute(route, '/{value}', web.HttpMethod.PATCH,
+        model_name = self.service.__blnt__.model_name
+        docstring = docstring or f"""
+        Updates some fields from one {model_name} entity, identified by {key} field
+
+        -response 200 returns: The updated {model_name} entity
+        """
+        return ControllerRoute(route, f'/{{{key}}}', web.HttpMethod.PATCH, docstring,
                                expects=Expects(self.service.__blnt__.model_name, expects, patch=True),
-                               returns=Returns(self.service.__blnt__.model_name, returns),
+                               returns=Returns(model_name, returns),
                                middlewares=middlewares)
 
-    def delete(self, returns='default', *, key='id', middlewares=None):
+    def delete(self, returns='default', *, key='id', middlewares: List[str] = None, docstring: str = None):
         async def route(controller, match, **kwargs):
-            entity = await controller.service.get_first_by(key, match.get('value'))
+            entity = await controller.service.get_first_by(key, match.get(key))
             resp = await functions.async_invoke(controller.service.delete, entity, **kwargs)
             return controller.response.ok(f'{controller.service.__blnt__.model_name}.deleted', resp)
 
-        return ControllerRoute(route, '/{value}', web.HttpMethod.DELETE,
-                               returns=Returns(self.service.__blnt__.model_name, returns),
+        model_name = self.service.__blnt__.model_name
+        docstring = docstring or f"""
+        Deletes on record from {model_name} collection, identified by {key} field
+
+        -response 200 returns: The deleted {model_name} entity
+        """
+        return ControllerRoute(route, f'/{{{key}}}', web.HttpMethod.DELETE, docstring,
+                               returns=Returns(model_name, returns),
                                middlewares=middlewares)
